%%-------------------------------------------------------------------------
% Main code for replicating COCHRANE(1994) chapter 6: multivariate time-series
%--------------------------------------------------------------------------

% -------------- Room saving ----------------------------------------------

close all; clear all; clc; pause(0.01), randn('seed',sum(clock)), rand('seed',sum(clock)), warning off
TSTART = tic;
% -------------- Load folders ---------------------------------------------

addpath([pwd '\Input\']);
addpath([pwd '\Utilities\']);
addpath([pwd '\Output\']);

% -------------- Import data  and transform -------------------------------
[data,textdata,raw] = xlsread('USAnnual.xls','Data');
% obs 1 is 1900, annual data 
US.P   = data(:,2);
US.D = data(:,3);
US.CPI      = data(:,5);
US.BondYTM  = data(:,8);
US.MY=data(:,7);
US.DPratio      = US.D./US.P;
US.LogDPratio   = log(US.DPratio);
US.LogP     = log(US.P);
US.LogD     = log(US.D);
US.DivGrowth    =NaN(size(US.P));
US.DivGrowth(2:end,:)    = diff(US.LogD);
US.LogCPI       = log(US.CPI);
US.Returns.Monthly    =NaN(size(US.P));
US.Infl    =NaN(size(US.P));
US.Returns.Monthly(2:end,:)  = log((US.P(2:end)+US.D(2:end))./US.P(1:end-1));
US.Infl(2:end,:)             = diff(US.LogCPI);

% Defining Sample 
ss=28; % Sample Start 1927
se=89; % Sample End 1988
ObsSample = se-ss+1; % Number of observations within Sample

%graphic analysis
t = [1:size((US.P))];
figure(1)
   plot(t(ss:se)',US.LogP(ss:se),t(ss:se)', 3+US.LogD(ss:se),'-','LineWidth',1);
title('  US  Price and Dividends  ','fontname','times','fontangle','italic','fontsize',18);
   set(gca,'fontname','times','fontangle','italic','fontsize',12,'gridlinestyle',':');
   index=ss:10:se;
set(gca,'fontname','garamond','fontsize',10);
set(gca,'xtick',index);
set(gca,'xticklabel','1927|1937|1947|1957|1967|1977|1987|1997|2007');
set(gca,'xlim',[ss se]);
grid;
set(gcf,'color','w');
h=legend('log Prices','log Dividends',1);

% set all the info to run CVAR
    x      = [US.LogD(ss:se) US.LogP(ss:se)];
    a      = [1;-1];
    lags   = 2;
    horiz  = 20;
    names  = {'d-p';'d';'p'} ;
% run CVAR   
[b,sigma,r,dxir,xir,statcom,e] = varEC(x,a,lags,horiz,names,1,1);
    z = [zeros(1+lags,1);(x(2+lags:rows(x),2)-statcom)];
%run univariate analysis
 lagu   = 2;
 varnum = 2;            % whose univariate i-r to calculate (element of x) 
[b1,stat1] = univar(x(:,varnum),lagu,horiz,names,1);       % note i-r normalized to sigma=1*/
        z1 = x(:,2)-[zeros(lagu+1,1);stat1];


%% graph multivariate impulse-response function
       figure(2)
        plot(seqa(0,1,horiz),xir(1:horiz,:));
        title('impulse-response of d,p system');
        ylabel('Response to a unit shock');
        %     xtics(0,horiz2,5,0);
        
        xlabel('Years after a unit shock'); 
                
        legend('d, d shock','p, d shock','d, p shock','p, p shock');
                
    
   
%%  graph P, B-N decomposition   
    px = seqa(1930,1,ObsSample-3);
    py = [x(4:end,2) z(4:end) ];
    figure(3)
    plot(px,py);
    xlabel('Date');
    ylabel('log P');
    legend('log P', 'VAR trend');
    title(' Multivariate Beveridge-Nelson trend ');
   
    
             
   




