function [Exp_z, Sigma_H, Exp_ret_nominal,Var_ret_nominal, Annual_Std,Corr_Tbills_Stocks,Corr_Tbills_Bonds,Corr_Stocks_Bonds]=GetCondMoments_ann(Z,Phi1,Phi0,Sigmani,max_mat)

 % This function extracts conditional moments for the matrix Z based on the
 % parameters we estimated before
 
 
A = Phi1;
B= Phi0;
Omega = Sigmani;
z=Z';
% ------ CONDITIONAL MOMENTS OF THE MATRIX Z -----%

% Expected values

Exp_z=zeros(rows(B),max_mat+1);
Exp_z(:,1)=z(:,cols(z));

for i=2:cols(Exp_z)
 Exp_z(:,i)=(B+A*Exp_z(:,i-1));
end

% Variances-Covariances

IA_factor = zeros(rows(A),cols(A),max_mat);
IA_factor(:,:,1) = eye(rows(A)); 
for i = 2:max_mat
   IA_factor(:,:,i) = IA_factor(:,:,i-1) + A^(i-1);
end

%form Sigma_H, Sigma_Zk, Cov_H_Zk

Sigma_H  = zeros(rows(A),cols(A),max_mat);
Sigma_Zk = zeros(rows(A),cols(A),max_mat);
Cov_H_Zk = zeros(rows(A),cols(A),max_mat);

Sigma_H(:,:,1)  = IA_factor(:,:,1)*Omega*IA_factor(:,:,1);
Sigma_Zk(:,:,1) = A^(1-1)*Omega*A^(1-1)';
Cov_H_Zk(:,:,1) = IA_factor(:,:,1)*Omega*A';

for i = 2:max_mat
   Sigma_H(:,:,i)  = Sigma_H(:,:,i-1)  + IA_factor(:,:,i)*Omega*IA_factor(:,:,i)';
   Sigma_Zk(:,:,i) = Sigma_Zk(:,:,i-1) + A^(i-1)*Omega*A^(i-1)';
   Cov_H_Zk(:,:,i) = Cov_H_Zk(:,:,i-1) + IA_factor(:,:,i)*Omega*A^(i)';
end

% ------ CONDITIONAL MOMENTS OF RETURNS ------%

%Choose one of the following definitions of selector matrix
Hr=[eye(3), zeros(3,3)];
% Hr=[1 0 0 0 0 0; ones(2,2) eye(2,2) zeros(2,2)];


Exp_ret_nominal=NaN(3,max_mat);
Var_ret_nominal=NaN(3,3,max_mat);
Nominal_ret=[Exp_z(1,:); (Exp_z(2,:)+Exp_z(4,:)); (Exp_z(3,:)+Exp_z(4,:)); Exp_z(4:end,:)];


for i=1:max_mat
Exp_ret_nominal(:,i)=(Hr*Nominal_ret(:,i+1))./i;
Var_ret_nominal(:,:,i)=(Hr*Sigma_H(:,:,i)*Hr')./i;  %K-period varcov matrix
end

%Representation of the results // Standard Deviations and Correlations

Std_nominal=NaN(max_mat,3);
Corr_nominal=NaN(size(Var_ret_nominal));
Corr_Tbills_Stocks=NaN(max_mat,1);
Corr_Tbills_Bonds=NaN(max_mat,1);
Corr_Stocks_Bonds=NaN(max_mat,1);

for i=1:max_mat
[Std_nominal(i,:),Corr_nominal(:,:,i)]=cov2corr(Var_ret_nominal(:,:,i));
Corr_Tbills_Stocks(i,1)=Corr_nominal(2,1,i);
Corr_Tbills_Bonds(i,1)=Corr_nominal(3,1,i);
Corr_Stocks_Bonds(i,1)=Corr_nominal(3,2,i);
end

% Var_nominal=NaN(max_mat,3);
% 
% for i=1:max_mat
% Var_nominal(i,:)=((diag(Var_ret_nominal(:,:,i)))');
% Std_nominal(i,:)=sqrt(Var_nominal(i,:));
% Corr_Tbills_Stocks(i,1)=Var_ret_nominal(1,2,i)/(Std_nominal(i,1)*Std_nominal(i,2));
% Corr_Tbills_Bonds(i,1)=Var_ret_nominal(1,3,i)/(Std_nominal(i,1)*Std_nominal(i,3));
% Corr_Stocks_Bonds(i,1)=Var_ret_nominal(2,3,i)/(Std_nominal(i,3)*Std_nominal(i,2));
% end

Annual_Std=Std_nominal.*100;
s=1:max_mat;

figure;
plot(s',Annual_Std(:,1),'k-');
hold on;
plot(s',Annual_Std(:,2),'k--');
hold on;
plot(s',Annual_Std(:,3),'k-.');
hold off;
set(gca,'fontname','garamond','fontsize',12);
xlabel('Horizon');
ylabel('Percentage Stdv');
title('Campbell-Viceira model. Percentage Standard deviations','fontname','garamond','fontsize',14,'Color', [.3 .3 .3]);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Garamond','fontsize',12);
legend('Tbills','Stocks','Bonds',0);

figure;
plot(s',Corr_Tbills_Stocks,'k-');
hold on;
plot(s',Corr_Tbills_Bonds,'k--');
hold on;
plot(s',Corr_Stocks_Bonds,'k-.');
hold off;
set(gca,'fontname','garamond','fontsize',12);
xlabel('Horizon');
ylabel('Correlations');
title('Campbell-Viceira model. Correlations of returns','fontname','garamond','fontsize',14,'Color', [.3 .3 .3]);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Garamond','fontsize',12);
legend('Tbills-Stocks','Tbills-Bonds','Stocks-Bonds',0);

end
