%% Campbell-Viceira replica

% ============== Original Campbell-Viceira dataset, 1890-1995
close all; clear all; clc; pause(0.01), randn('seed',sum(clock)), rand('seed',sum(clock)), warning off
TSTART = tic;
% -------------- Load folders ---------------------------------------------

addpath([pwd '\util\']);

% -------------- Import data  and transform -------------------------------
[filename,pathname]=uigetfile('*.asc');      %Select file "Data_ANN.asc"

% Source: % http://dvn.iq.harvard.edu/dvn/dv/jcampbell/faces/subsetting/SubsettingPage.xhtml?dtId=1139&versionNumber=1

importfile(filename); 

% -----GET THE Z TIME SERIES ------% 

[Z_simple,date] = GetDataANN(dataANN,3);

% Replica original sample / re-estimate on full sample

Z=[Z_simple(62:end,1:3) Z_simple(62:end,4:6)];
Z=[Z_simple(62:end,1:3) Z_simple(62:end,4:6)];

% Relevant Statistics

Mean_Tbillreal=(mean(Z(:,1))+var(Z(:,1))/2);
Std_Tbillreal=std((Z(:,1)));
Mean_Stocks_excess=(mean(Z(:,2))+var(Z(:,2))/2);
Std_Stocks_excess=(std(Z(:,2)));
Sratio_Stocks_excess=Mean_Stocks_excess/Std_Stocks_excess;
Mean_Bonds_excess=(mean(Z(:,3))+var(Z(:,3))/2);
Std_Bonds_excess=(std(Z(:,3)));
Sratio_Bonds_excess=Mean_Bonds_excess/Std_Bonds_excess;
Mean_Tbillnominal=(mean(Z(:,4)));
Std_Tbillnominal=(std(Z(:,4)));
Mean_LogdivYield=(mean(Z(:,5)));
Std_LogdivYield=(std(Z(:,5)));
Mean_Yieldspread=(mean(Z(:,6)));
Std_Yieldspread=(std(Z(:,6)));

% ----------    ESTIMATE THE PARAMETERS OF THE VAR(1)   -------------%

[Phi0,Phi1,tPhi0,tPhi1,Sigmani,RSqvec,Corrv] = GetParms_res(Z,1,0,1);   

% ------  CALCULATE EXPECTED VALUES AND VARIANCES AS FUNCTION OF MATURITY -------- %

max_mat=40;  % Define the horizon

[Exp_z, Sigma_H,Exp_ret_nominal,Var_ret_nominal, Annual_Std,Correlation]=GetCondMoments_ann(Z,Phi1,Phi0,Sigmani,max_mat);

%% K-period Mean-variance analysis; Longevity Shocks have lowest risk

% The following part of the function represents the Global Minimum Variance Portfolio
% as a function of maturity and correspondingly computes its variance

% Decomposition of the Sigma matrix    
% Sigmani is equal to [Sigma2zero Sigmazerox'Sigmazeros'; Sigmazerox Sigmaxx Sigmaxs';
% Sigmazeros Sigmaxs Sigmas]

Sigma2x=NaN(2,max_mat);
Sigma2zero=NaN(1,max_mat);
Sigmazerox=NaN(2,max_mat);
Sigmaxx=NaN(2,2,max_mat);

for i=1:max_mat
% Exp_ret_x(:,i)=Exp_ret(2:rows(Exp_ret),i);
Sigmaxx(:,:,i)=Var_ret_nominal(2:3,2:3,i);
Sigma2x(:,i)=diag(Sigmaxx(:,:,i));
Sigma2zero(:,i)=Var_ret_nominal(1,1,i);
Sigmazerox(:,i)=Var_ret_nominal(2:3,1,i);
end

% ------------  FIND THE GMV COMPOSITION   --------------   % 

GMV_no_riskless=NaN(3,max_mat);
for i=1:max_mat
   GMV_no_riskless(2:3,i)=-inv(Sigmaxx(:,:,i))*Sigmazerox(:,i);
   GMV_no_riskless(1,i)=1-sum(GMV_no_riskless(2:3,i));
end

% Plot results

k=1:max_mat;
figure;
plot(k',GMV_no_riskless(1,:)','k-');
hold on
plot(k',GMV_no_riskless(2,:)','k--');
hold on
plot(k',GMV_no_riskless(3,:)','k-.');
hold off;
set(gca,'fontname','garamond','fontsize',12);
xlabel('Horizon');
ylabel('Composition');
title('Campbell-Viceira model. Composition of GMV portfolio','fontname','garamond','fontsize',14,'Color', [.3 .3 .3]);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Garamond','fontsize',12);
legend('Tbills','Stocks','Bonds',0);


%  ------------------  GMV VARIANCE   --------------------  %

Var_GMV_k=NaN(max_mat,1);

for i=1:max_mat
  Var_GMV_k(i,1)=GMV_no_riskless(2:3,i)'*Sigmaxx(:,:,i)*GMV_no_riskless(2:3,i)+Sigma2zero(1,i)+2.*GMV_no_riskless(2:3,i)'*Sigmazerox(:,i);
end

Std_GMV=sqrt(Var_GMV_k);

Annual_Std_GMV=Std_GMV.*100;
s=1:max_mat;
figure;
plot(s',Annual_Std(:,1),'-k',s',Annual_Std_GMV,'--k');
set(gca,'fontname','garamond','fontsize',12);
xlabel('Horizon');
ylabel('Percentage Stdv');
title('Campbell-Viceira model. Risk of T-bills and GMV','fontname','garamond','fontsize',14,'Color', [.3 .3 .3]);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Garamond','fontsize',12);
legend('Tbills','GMV',0);

%% Efficient frontier for different investment horizons; no risk-free asset

horizons=[2 5 10 15 20]';

for i=1:rows(horizons)

%We calculate mean returns and the variance-covariance matrix. For the
%example we will assume that these quantities are our future expectations

mu=Exp_ret_nominal(:,horizons(i,1));
V=Var_ret_nominal(:,:,horizons(i,1));

%We create the vector of ones
one=ones(size(mu));

A=(one'/V)*mu;
B=(mu'/V)*mu;
C=(one'/V)*one;
D=B*C-A^2;

%We can now calculate g and h
g=(B*(V\one)-A*(V\mu))/D;
h=(C*(V\mu)-A*(V\one))/D;

%Now we produce a vector of equally spaced expected returns
ret=linspace(0,max(mu),20);

%We also create empty matrices to record the efficient portfolios
%composition and risk
w=zeros(size(mu,1),size(ret,2));
risk=zeros(rows(ret),cols(ret));

%For each return we calculate the optimal portfolio composition
for u=1:size(ret,2)
    w(:,u)=g+h*ret(u);
    risk(1,u)=sqrt(w(:,u)'*V*w(:,u));
end

figure
bar(100*ret,w')
grid on
title('Portfolio Weights,');
xlabel('Portfolio Return %')
legend('T-Bill','Long Bond','Stocks')

figure
plot(risk,ret,'b-o')
grid on
title('Minimum Variance Frontier')
xlabel('Portfolio Risk')
ylabel('Portfolio Return')

end

%% Composition of G and H for different investment horizons

G=zeros(3,max_mat);
H=zeros(3,max_mat);

for i=1:max_mat

%We calculate mean returns and the variance-covariance matrix. For the
%example we will assume that these quantities are our future expectations

mu=Exp_ret_nominal(:,i);
V=Var_ret_nominal(:,:,i);

%We create the vector of ones
one=ones(size(mu));

A=(one'/V)*mu;
B=(mu'/V)*mu;
C=(one'/V)*one;
D=B*C-A^2;

%We can now calculate g and h for different horizons
G(:,i)=(B*(V\one)-A*(V\mu))/D;
H(:,i)=(C*(V\mu)-A*(V\one))/D;

end

horz=1:max_mat;

figure
plot(horz',G')
grid on
title('Optimal Portfolio Weights 0% return');
xlabel('Horizon')
legend('T-Bill','Long Bond','Stocks')

figure
plot(horz',G'+0.07*(H'))
grid on
title('Optimal Portfolio Weights 7% Returns');
xlabel('Horizon')
legend('T-Bill','Long Bond','Stocks')
