% -- Use the Implied Delta for all Calculations -- %
if exist('ImpliedDelta');
	delta = ImpliedDelta;
end      
% -- Regroup the coefficients in vecB2B2 -- %
B2B2 = GetB2B2(vecB2B2);
      
% ---- Calculates some Statistics ---- %
% ~~ 1. Consumption-Wealth ratio: E(C/W) = exp(E(c-w))*100 ~~ %
ecw = b0+B1'*muState+vecB2B2'*vec(sigmaState+muState*muState');
ECW = exp(ecw)*100;
      
% ~~ 2. Expected Value function: E(V) = constant*E[(C/W)^(1/1-psi)] ~~ %
% -- Approximate by constant*exp(E(c-w)*const)*100 -- %
EV = ((1-delta)^(-psi/(1-psi)))*exp((1/(1-psi))*ecw)*100;

% ~~ 3. Expected Asset Holdings: E(alpha(t)) ~~ %
Ealpha = (A0 + A1*muState)*100;
      
% ~~ 4. Unconditional Volatility of Consumption Growth ~~ %      
VARvv = GetVARvv(SIGMAv,rows(PHI0));
tmp1 = B1'+2*PHI0'*.5*(B2B2+B2B2')+A0'*Hx+H1;
tmp2 = 2*PHI1'*.5*(B2B2+B2B2') + A1'*Hx;
tmp3 = tmp1*SIGMAv*tmp1' + muState'*tmp2*SIGMAv*tmp1' + tmp1*SIGMAv*tmp2'*muState + (vec(sigmaState+muState*muState'))'*vec(tmp2*SIGMAv*tmp2')+vec(B2B2)'*VARvv*vec(B2B2);
volcg = sqrt(tmp3)*100;
      
% ~~ 5. Hedging Demands ~~ %
n = rows(Hx)+1;
iota = ones(n-1,1);
SIGMA1x = Hx*SIGMAv*H1';
SIGMAxx = Hx*SIGMAv*Hx';
sigma11 = SIGMAv(1,1);
d = diag(SIGMAxx);
         
LAMDA0 = (SIGMAv*Hx')'*B1 + 2*(SIGMAv*Hx')'*.5*(B2B2+B2B2')*PHI0;
LAMDA1 = 2*(SIGMAv*Hx')'*.5*(B2B2+B2B2')*PHI1;

myopicD = (1/gama)*inv(SIGMAxx)*(Hx*PHI0+Hx*PHI1*muState+0.5*d+(1-gama)*SIGMA1x )*100;
hedgeD = -(1/gama)*inv(SIGMAxx)*( ((1-gama)/(psi-1))*(LAMDA0+LAMDA1*muState) )*100;
HedgeRatio = (hedgeD./Ealpha)*100;


% ~~ 6. Unconditional Mean Return of Portfolio: E(r(p)) ~~ %
GAMMA0 = A0'*Hx*PHI0 + H1*PHI0 + (1/2)*A0'*d - (1/2)*A0'*SIGMAxx*A0;
GAMMA1 = PHI0'*Hx'*A1 + A0'*Hx*PHI1 + H1*PHI1 + (1/2)*d'*A1 - A0'*SIGMAxx*A1;
GAMMA2 = vec(A1'*Hx*PHI1)' - (1/2)*vec(A1'*SIGMAxx*A1)' ;
E_rp = (GAMMA0 + GAMMA1*muState + GAMMA2*vec(sigmaState + muState*muState'))*100;
         
% ~~ 7. Unconditional Volatility of Portfolio Return ~~ %
K1 = PHI0'*Hx'*A1 + A0'*Hx*PHI1 + H1*PHI1 + 0.5*d'*A1 - (sigma11/2)*iota'*A1 - A0'*SIGMAxx*A1 - SIGMA1x'*A1 ;
K2 = A0'*Hx + H1;
K3 = A1'*Hx;
K4 = vec(A1'*Hx*PHI1 - 0.5*A1'*SIGMAxx*A1)';
Var_rp1 = K1*sigmaState*K1' + K2*SIGMAv*K2' + vec(K3*SIGMAv*K3')'*vec(sigmaState + muState*muState') + 2*K2*SIGMAv*K3'*muState;
varvecZZ = (eye((rows(SIGMAv))^2) + GetK(rows(SIGMAv)))*( kron(sigmaState,sigmaState) + kron(sigmaState,muState*muState') + kron(muState*muState', sigmaState));
Var_rp2 = K4*varvecZZ*K4';
Var_rp = Var_rp1 + Var_rp2;
vol_rp = sqrt(Var_rp)*100;
         
CondDemand = 0;
if CondDemand == 1        
   % ~~ 8. Calculate Demand Conditional on D/P ~~ %
   if (gama == 2 & psi == 0.99)            
     	muCondVar  = mean(dataOUT(:,4));
     	stdCondVar = std(dataOUT(:,4));
      lowlimit = (muCondVar - 3*stdCondVar);
      incre = 6*stdCondVar/20;
   	uplimit = muCondVar + 3*stdCondVar;
	   Cond_D_stock_mat = [];
      Cond_D_bond_mat = [];
      for value = lowlimit:incre:uplimit
      	zFitted = zFittedValue(dataOUT,4,value);			% zFitted = E(Z(t)|d/p).            
   	   Cond_D = (A0 + A1*zFitted)*100;
  	      Cond_D_stock_mat  = [Cond_D_stock_mat; Cond_D(1)];
			Cond_D_bond_mat  = [Cond_D_bond_mat; Cond_D(2)];
      end;
   end
end
