if exist('uberbatchon')
	keep uberbatchon AssetUsed StateVariableUsed RunTables
else
	clear;
end

filename = [];
uberfilename = [];

diaryFLAG = 1;

%%% SETTINGS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   nosave = 0;

   psiID = 1;			%1 : psi = 1
				%2 : psi = 1 / gamma
				%2 : psi = .5 (now)

   SampleFreq = 2;		%2 : quarterly
				%3 : annual

   deltaORIG = .92;

   % State Variables -- all possible state variables for use
   %       0) Constant
   %       1) Nominal short rate 
   %       2) Stock, excess return over nominal short rate
   %       3) Nominal bond, excess return over nominal short rate
   %       4) Consol bond, excess return over nominal short rate
   %       5) Nominal short yield
   %       6) Dividend-price ratio
   %       7) Yield spread

   if ~exist('uberbatchon')
	StateVariableUsed = [1 1 1 0 1 1 1]; 
   end          %0/1 vector indicating whether state variable is to be used in the VAR.

   if ~exist('uberbatchon')
   	AssetUsed = [0 1 1 0 0 0 0]; 
   end          %0/1 vector indicating whether asset is to be used in portfolio choice

   RCBposition_original = 4;
		%Do not change unless entire specification is modified!!!
		%Purpose is to help track position of real consol bond, see below

   % Must track use of real consol bond in order to compute VAR correctly
   % within portfolio choice exercise.

   if StateVariableUsed(RCBposition_original)
	RCBposition = sum(StateVariableUsed(1:RCBposition_original));
   else
	RCBposition = [];
   end



   AU = [];
   if AssetUsed(2)
	AU = [AU 'S'];
   end
   if AssetUsed(3)
	AU = [AU 'N'];
   end
   if AssetUsed(4)
	AU = [AU 'R'];
   end

   disp(['Assets used: ' AU]);

   if max(size(AU))==1
	AU = [AU '__']
   elseif max(size(AU))==2
	AU = [AU '_']
   end
   if ((or(sum(AU == 'SNR')==3 , sum(AU == 'SR_')==3)))
%	   gama_uber = [1];
	   gama_uber = [1 2 5 20 2000];
%	   gama_uber = [250];
   else
%	   gama_uber = [1];
	   gama_uber = [1 2 5 20];
%	   gama_uber = [250];

   end


			%gamma values at which the program will be run

   PROG = 'ISV';		%'ISV' = Influence of State Variables
				%'VDC' = Variance Decomposition
				%'VAR' = VAR only, for table output

   if sum(PROG == 'VDC')==3
	gama_uber = 5;
   elseif sum(PROG == 'VAR')==3
	gama_uber = 1;
   end

   PSIVALUE = .99;		% Approximation to psi = 1 used in the programs.
   PSIVALUE_2 = .5;		%

   SubSample = 0;		%0 : full sample
				%1 : through 1979 (qtrly only)
				%2 : post 1979 (qtrly only)


   ForPlot = 0;			%0 : regular mode
				%1 : is being run to get asset allocations
				%    only, doesn't save huge files each
				%    time.

   if ForPlot == 1;
	   gama_uber = linspace(1,20,40);
	   gama_uber =[ gama_uber 40 80 160 320 600 1200 2000];
   end

   RunTables = 1;

   EXPER = '';

%%% END SETTINGS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if SampleFreq == 2; AQ = 'Q'; else; AQ  = 'A'; end;
alloc_store = [];

% Run programs at different gamma's to get files, saved as name designated by variable 'savefile'
for ubercounter = 1:max(size(gama_uber))
	keep gama_uber ubercounter uberfilename psiID SampleFreq PROG SubSample AQ alloc_store ForPlot nosave PSIVALUE AU RunTables AssetUsed StateVariableUsed RCBposition uberbatchon PSIVALUE_2 deltaORIG EXPER
	gamavec = gama_uber(ubercounter);
	GV = num2str(gamavec/10000,'%10.4f');

	if (sum(StateVariableUsed) >= 7)
		filenametemp = strcat( PROG,'_', AQ, '_g', GV(3:6), '_pID', num2str(psiID), '_', AU, EXPER)
	else
		filenametemp = strcat( PROG,'_', AQ, '_g', GV(3:6), '_pID', num2str(psiID), '_', AU, '_s', EXPER)
	end	

	uberfilename = [uberfilename;filenametemp];
	savefile = uberfilename(ubercounter,:);
	if ForPlot == 1
		diaryfile = 'trash';
	end

	main_replacement

	if ForPlot == 1
		!rm trash.*
		alloc_store = [alloc_store; myopicD' hedgeD'] 
	end
end



% Create TeX tables for output in paper

if RunTables
	
	if ForPlot == 0
	
		if sum(PROG == 'ISV')==3

			% Set the filenames to be loaded by the TexTable* programs	
			File1 = uberfilename(1,:);
			File2 = uberfilename(2,:);
			File3 = uberfilename(3,:);
			File4 = uberfilename(4,:);
			if (or(sum(AU == 'SNR')==3 , sum(AU == 'SR_')==3))
				File5 = uberfilename(5,:);
			end
			% Set name of table
			TableName = strcat('Table_ISV_', AQ, '_pID', num2str(psiID), '_', AU, '.tex')

			% Run appropriate TeX table-generating program.

			if and(sum(AU == 'SNR')==3, sum(StateVariableUsed == [1 1 1 1 1 1 1])==max(size(StateVariableUsed))); 

				TexTable_ISV_SNR;

			elseif and(sum(AU == 'SR_')==3, sum(StateVariableUsed == [1 1 0 1 1 1 1])==max(size(StateVariableUsed))); 

				TexTable_ISV_SR_; 

			elseif and(sum(AU == 'SN_')==3, sum(StateVariableUsed == [1 1 1 0 1 1 1])==max(size(StateVariableUsed))); 

				TexTable_ISV_SN_;

			end

		elseif sum(PROG == 'VDC')==3

			File1 = uberfilename(1,:);
			TableName = strcat('Table_VDC_', AQ, '_pID', num2str(psiID), '_', AU, '.tex')
			TexTable_VDCa;

		elseif sum(PROG == 'VAR')==3

		end
	
	elseif ForPlot == 1
	
	
		FileName = strcat('GammaPlotData', AQ, '_pID', num2str(psiID), '_', AU, '.mat')
		save(FileName,'alloc_store','gama_uber', 'AU');
	
	end
end
	
