    
%--------------------------------------------------------------------------
% SECTION 2: Dynamic Models and Spurious Regressions
%--------------------------------------------------------------------------
%----------------------------------------------------------------------
% DYNAMIC REGRESSIONS 
%----------------------------------------------------------------------
US.ldiv_lag=NaN(rows(US.p),1);
US.ldiv_lag=lag(US.ldiv,1,NaN);
UK.ldiv_lag=NaN(rows(US.p),1);
UK.ldiv_lag=lag(UK.ldiv,1,NaN);
UK.lp_lag=NaN(rows(US.p),1);
UK.lp_lag=lag(UK.lp,1,NaN);
clear X2 X;
X2=NaN(rows(US.p),3);
X2(:,1)=UK.lp_lag(:,1);
X2(:,2)=US.ldiv_lag(:,1);
X2(:,3)=UK.ldiv_lag(:,1);

country=strvcat('USdiv_dyn','UKdiv_dyn');

for i=1:2

X=NaN(rows(US.p),4);
X(:,1)=ones;
X(:,2)=X2(:,1);
X(:,3)=X2(:,1+i);
X(:,4)=t';

result=ols(LP(first:last,2), X(first:last,:));
beta=result.beta;
tstat=result.tstat;
R2=result.rsqr;

var1=strcat('beta1',country(i,:));
assignin('base',var1,beta);
var2=strcat('tstat1',country(i,:));
assignin('base',var2,tstat);
var3=strcat('R21',(country(i,:)));
assignin('base',var3,R2);
var4=strcat('result',(country(i,:)));
assignin('base',var4,result);

clear result beta tstat var1 var2 var3 var4

end
country=strvcat('USdiv_dyn','UKdiv_dyn');
clear X
for i=1:2

X=NaN(rows(US.p),3);
X(:,1)=X2(:,1);
X(:,2)=X2(:,1+i);
X(:,3)=t';
spec1=garchset('Regress',[1 1 1]);
[coeff,errors,llf,innovation,sigma,summary]= garchfit(spec1,LP(first+2:last,2),X(first+2:last,:));
garchdisp(coeff,errors);

end
    
%----------------------------------------------------------------------
% Non-Stationary Time-Series, cointegration and ECM
%----------------------------------------------------------------------
    figure
    [AX,H1,H2] = plotyy(t,UK.ldiv+1.3,t,UK.lp);
set(get(AX(1),'Ylabel'),'String','UK (log) dividends','Fontsize',12);
set(AX(1),'YTick',[2 4 6 8]);
set(get(AX(2),'Ylabel'),'String','UK (log)Price ','Fontsize',12);
set(AX(2),'YTick',[ 4 6 8 10]);
set(H1,'LineStyle','--','LineWidth',2);
set(H2,'LineStyle',':','LineWidth',2);
xlabel('Years');
title('Dividend  vs Price','Fontsize',14);
set(AX(1:2),'XTick',1:8:rows(t'));
set(AX(1:2),'xticklabel','1973|1975|1977|1979|1981|1983|1985|1987|1989|1991|1993|1995|1997|1999|2001|2003|2005|2007|2009|2011');
set(AX(1:2),'xlim',[0 rows(t')]);
grid;
%----------------------------------------------------------------------
% ERROR CORRECTION MODEL 
%----------------------------------------------------------------------
%----------------------------------------------------------------------
% one simulation 
%----------------------------------------------------------------------
disp('================================================================')
disp('one simulation')
clear xt yt yt2 zt u1 u2 u3 vol1 vol2 vol3 
% Error terms:
vol1=0.1;
vol2=0.02;
vol3=0.01;
u1=NaN(rows(US.p),1);
u2=NaN(rows(US.p),1);
u3=NaN(rows(US.p),1);
xt=NaN(rows(US.p),1);
yt=NaN(rows(US.p),1);
yt2=NaN(rows(US.p),1);
zt=NaN(rows(US.p),1);

u1(first:last,1)=vol1.*normrnd(0,1,last-first+1,1);
u2(first:last,1)=vol2.*normrnd(0,1,last-first+1,1);
u3(first:last,1)=vol3.*normrnd(0,1,last-first+1,1);

% Initializing the series:
xt(first,1)=UK.lp(first,1);
yt(first,1)=UK.lp(first,1);
yt2(first,1)=UK.lp(first,1);
zt(first,1)=UK.lp(first,1);

% Artificial series:
for i=first:last-1
    xt(i+1,1)=0.05+1*xt(i,1)+u1(i,1);
    yt(i+1,1)=0.05+yt(i,1)-0.15*(yt(i,1)-xt(i,1))+u2(i,1);
    zt(i+1,1)=0.02+1*zt(i,1)+u3(i,1);
end

% Plot the results:
figure;
plot(t(:,first:last)',xt(first:last),t(:,first:last)',yt(first:last),'-','LineWidth',2);
set(gca,'fontname','garamond','fontsize',10);
set(gca, 'xtick', [1:8:rows(t')]);
set(gca,'xlim', [1 rows(t')]);
set(gca,'xticklabel','1973|1975|1977|1979|1981|1983|1985|1987|1989|1991|1993|1995|1997|1999|2001|2003|2005|2007|2009|2011');
title('Artificial Series: coeff = - 0.15','fontname','garamond','fontsize',16);
h = legend('xt', 'yt' ,'zt',0);
grid;
set(gcf,'color','w');

%alternative speed of adjustment

for i=first:last-1
yt2(i+1,1)=0.05+yt2(i,1)-0.80*(yt2(i,1)-xt(i,1))+u2(i,1);
end

% Compare the results with the two different speed of adjustments

param=strvcat(' coeff = - 0.15', ' coeff = - 0.8');
var=strvcat('yt','yt2');
X1=[(yt-xt) (yt2-xt)];

figure;
for i=1:2
subplot(1,2,i)
X=[ X1(:,i)];
plot(X)
set(gca,'fontname','garamond','fontsize',10);
set(gca, 'xtick', [1:12:rows(t')]);
set(gca,'xlim', [1 rows(t')]);
set(gca,'xticklabel','1973|1976|1979|1982|1985|1988|1991|1994|1997|2000|2003|2006|2009');
tit=strcat('Artificial Series: ', param(i,:));
title(tit,'fontname','garamond','fontsize',12);
tit2=(var(i,:));
h = legend('yt-xt',tit2,0);
grid;
set(gcf,'color','w');
end
disp('-----------------------------------------------------------------')


%----------------------------------------------------------------------
% Static Regressions and dynamic models:A MONTE CARLO EXPERIMENT
%----------------------------------------------------------------------
% Generate error terms :
clear x y z u1 u2 u3 beta1 beta3 rho1 rho2 
vol=0.01;
reps=100;
obs=200;
x=NaN(obs,reps);
y=NaN(obs,reps);
z=NaN(obs,reps);
u1=NaN(obs,reps);
u2=NaN(obs,reps);
u3=NaN(obs,reps);
beta1=NaN(1,reps);
beta3=NaN(1,reps);
rho1=NaN(1,reps);
rho2=NaN(1,reps);
% Initializing the series:
x(1,:)=1;
y(1,:)=1;
z(1,:)=1;
% Artificial series:
u1=vol.*normrnd(0,1,obs,reps);
u2=vol.*normrnd(0,1,obs,reps);
u3=vol.*normrnd(0,1,obs,reps);
 for j=1:reps  
for i=2:obs
x(i,j)=0.05+x(i-1,j)+u1(i,j); 
y(i,j)=0.05+y(i-1,j)-0.15*(y(i-1,j)-x(i-1,j))+u2(i,j);
z(i,j)=0.02+z(i-1,j)+u3(i,j);
end
X=NaN(obs,2);
X(:,1)=ones;
X(:,2)=x(:,j);
reg1=ols(y(1:obs,j), X(1:obs,:));
beta1(1,j)=reg1.beta(2);
uhat1=reg1.resid;
spec=garchset('variancemodel','constant','r',1);
[coeff]=garchfit(spec, uhat1(1:200,:));
rho1(1,j)=coeff.AR;
X(:,2)=z(:,j);
reg2=ols(y(1:obs,j), X(1:obs,:));
beta3(1,j)=reg2.beta(2);
uhat2=reg2.resid;
[coeff]=garchfit(spec, uhat2(1:200,:));
rho2(1,j)=coeff.AR;
clear coeff reg1 reg2 uhat1 uhat2 X spec 
end
figure;
hist (beta1);
figure;
hist (beta3)
figure;
hist (rho1);
figure;
hist (rho2);