    
%----------------------------------------------------------------------
% ECM MODEL AT DIFFERENT HORIZONS 
%----------------------------------------------------------------------

disp('================================================================')
disp('ECM')
date=datenum(textdata(4:end,1),'dd/mm/yyyy');
f3=['31/12/1976'];
f4=['31/12/2012'];
date_find3=datenum(f3,'dd/mm/yyyy');
date_find4=datenum(f4,'dd/mm/yyyy');
first=datefind(date_find3,date);
last=datefind(date_find4,date);

RET=NaN(rows(US.p),4);
RET(:,1)=0.25*UK.ret_1r;
RET(:,2)=UK.ret_4r;
RET(:,3)=2*UK.ret_8r;
RET(:,4)=3*UK.ret_12r;

DY=NaN(rows(US.p),1);
DY(:,1)=UK.ldp(:,1);

horizon=strvcat('1Q','4Q','8Q','12Q');

clear X;
X=NaN(rows(US.p),2);
X(:,1)=ones;
X(:,2)=DY(:,1);

result1Q=ols(RET(first+1:last, 1),X(first:last-1,:));
r2_1Q=result1Q.rsqr;
var1=strcat('result','1Q');
assignin('base',var1,result1Q);
var2=strcat('R2','1Q');
assignin('base',var2,r2_1Q);
clear var1
for i=1:3
    result=ols(RET(first+1:last, i + 1),X(first+1-i*4:last-i*4,:));
    r2_q=result.rsqr;
    var3=strcat('result',(horizon(i+1,:)));
    assignin('base',var3,result);
    var4=strcat('R2',horizon(i+1,:));
    assignin('base',var4,r2_q);
    clear var1 var2 var3 var4
end;
clear X;

%% Valkanov T-stats

%% Number of Iterations
rep = 5000;
%% critical values

% set matrixes
spec=garchset('variancemodel','Constant','R',1);
lgs = [1 4 8 12 ];
T=last-first+1;
lambda = lgs./T;
R=RET;
ldp = UK.ldp;
m=cols(R);
%c_cons=NaN(1,m);
% set empty tables
tableq = NaN(3,m);
statVK = NaN(1,m);
beta= NaN(1,m);
tstat= NaN(1,m);
resids=NaN(last-first,m);
delta=NaN(2,2,m);
% select if you want consistent proxy for autocorrelation or not
consistent=1;
%consistent=0;

% algorithm
for jj=1:m
% predictive regression
lg           = lgs(1,jj);
resultsDP    = ols(R(first+1:last,jj),[ones(last-first,1) ldp(first+1-lg:last-lg)]);  
beta(1,jj)     = resultsDP.beta(2); tstat(1,jj) = resultsDP.tstat(2); resids(:,jj) = resultsDP.resid;
statVK(1,jj) = tstat(1,jj)/sqrt(T);
% AR(1) ldp
[coeff_ldp,errors_ldp,llf_ldp,innovation_ldp,sigma_ldp,summary_ldp]=garchfit(spec, ldp(first+1:last));
delta(:,:,jj) = corrcoef(innovation_ldp,resids(:,jj));
end

% values for c
c_cons =log(1-beta(1,m))/lambda(1,m);

% values for phi
if consistent==1
    phi = 1 + c_cons/T;
elseif consistent==0
    phi = coeff_ldp.AR;
end

mu = 0; alpha = 0; mu_noise =[0 0];
k= floor(lambda(1,jj) * T);
% matrix for critical values
tstatVK = NaN(rep,1);

%% Null Hypothesis 
betahat = 0; %case 1 - Valkanov (2003)

%%
       for ii=1:rep

            starty=0;
            %Routine
            y=starty*ones(T+1,1); x=starty*ones(T+1,1);            
            % Generate values from a bivariate normal distribution with specified mean
            % vector and covariance matrix.
            D = chol(delta(:,:,1));
            e = repmat(mu_noise,T+1,1) + randn(T+1,2)*D;
            
            for i=1:T
                x(i+1,1) =  mu    + phi   * x(i,1)+e(i+1,2);
                y(i+1,1) =  alpha + betahat*x(i,1)+e(i+1,1);
            end
            
            x = trimr(x,1,0); % Tx1
            y = trimr(y,1,0); % Tx1
            
            Z = zeros(T,1); temp=y;
            for i=1:k
                temp = [y(1+i:end);  zeros(i,1)];
                Z = Z + temp;
            end
            Z = trimr(Z,0,k);
            x1 = trimr(x,0,k); 
            smpl_range = size(x1,1); X = [ones(smpl_range,1) x1];
            
            results = ols(Z,X);
            tstatVK(ii) = results.tstat(2);
        end
        % a useful summary of tails
        tableq(:,1) = quantile(tstatVK(:)/sqrt(T),[.90 .95 .99])';
        
%% Tables
clc;
disp('------------------Quantiles------------------')
fprintf('       ');   fprintf('\n');
 fprintf('0.90   ');  fprintf('%5.5f ',tableq(1,1)); fprintf('\n');
 fprintf('0.95   ');  fprintf('%5.5f ',tableq(2,1)); fprintf('\n');
 fprintf('0.99   ');  fprintf('%5.5f ',tableq(3,1)); fprintf('\n');
disp('----------------------------------------------')
disp('-----------Tstats in the Regressions----------')
fprintf('       ');  fprintf('  1 Q  '); fprintf('  4 Qs  '); fprintf('  8 Qs  '); fprintf('  12 Qs '); fprintf('\n');
 fprintf('Actual ');  fprintf('%5.5f ',statVK(1,1)); fprintf('%5.5f ',statVK(1,2)); fprintf('%5.5f ',statVK(1,3)); fprintf('%5.5f ',statVK(1,4));fprintf('\n');
disp('----------------------------------------------')




   