%%-------------------------------------------------------------------------
% Main code for replicating COCHRANE(1994) chapter 6: multivariate time-series
%--------------------------------------------------------------------------

% Defining Sample 
date=datenum(textdata(4:end,1),'dd/mm/yyyy');
f3=['31/03/1974'];
f4=['31/12/2012'];
date_find3=datenum(f3,'dd/mm/yyyy');
date_find4=datenum(f4,'dd/mm/yyyy');
ss=datefind(date_find3,date);
se=datefind(date_find4,date);

ObsSample = se-ss+1; % Number of observations within Sample

%graphic analysis
t = [1:size((US.p))];
figure(1)
   plot(t(ss:se)',US.lp(ss:se),t(ss:se)', 3.5+US.ldiv(ss:se),'-','LineWidth',1);
title('  US  Price and Dividends  ','fontname','times','fontangle','italic','fontsize',18);
   set(gca,'fontname','times','fontangle','italic','fontsize',12,'gridlinestyle',':');
   index=ss:20:se;
set(gca,'fontname','garamond','fontsize',10);
set(gca,'xtick',index);
set(gca,'xticklabel','1974|1979|1984|1989|1994|1999|2004|2009');
set(gca,'xlim',[ss se]);
grid;
set(gcf,'color','w');
h=legend('log Prices','log Dividends',1);

% set all the info to run CVAR
    x      = [US.ldiv(ss:se) US.lp(ss:se)];
    a      = [1;-1];
    lags   = 2;
    horiz  = 20;
    names  = {'d-p';'d';'p'} ;
% run CVAR   
[b,sigma,r,dxir,xir,statcom,e] = varEC(x,a,lags,horiz,names,1,1);
    z = [zeros(1+lags,1);(x(2+lags:rows(x),2)-statcom)];
%run univariate analysis
 lagu   = 2;
 varnum = 2;            % whose univariate i-r to calculate (element of x) 
[b1,stat1] = univar(x(:,varnum),lagu,horiz,names,1);       % note i-r normalized to sigma=1*/
        z1 = x(:,2)-[zeros(lagu+1,1);stat1];


%% graph multivariate impulse-response function
       figure(2)
        plot(seqa(0,1,horiz),xir(1:horiz,:));
        title('impulse-response of d,p system');
        ylabel('Response to a unit shock');
        %     xtics(0,horiz2,5,0);
        
        xlabel('Years after a unit shock'); 
                
        legend('d, d shock','p, d shock','d, p shock','p, p shock');
                
    
   
%%  graph P, B-N decomposition   
    px = seqa(1976.25,.25,ObsSample-3); 
    py = [x(4:end,2) z(4:end) ];
    figure(3)
    plot(px,py);
    xlabel('Date');
    ylabel('log P');
    legend('log P', 'VAR trend');
    title(' Multivariate Beveridge-Nelson trend ');
   
    
             
   




