function [b1,stat] = univar(x,lags,horiz,names,prnt)
% /* ------------------------------------------------------------------------ */
% /*                                univar.g                                  */
% /* runs Dx on lags of Dx.  finds BN decomposition                                       */
% 
% /*
%    Usage:
%      {b1,dxir1,xir1,stat} = univar(x,lags,horiz,prnt);
%    Inputs:
%      x:         series to do.  levels, e.g. log GNP
%      lags:      how many lagged differences to use
%      horiz:     how far to do impulse response
%      prnt:      1: print out results, 0: just return b and ir fn.
%    Returns:
%      b1:        regression coefficients.  [const Dx(t-1) Dx(t-2)...];
%      %     note lag polynomial is normalized to unit shock variance, not c(o) = 1;
% 


    T  = rows(x);
    Dx = x(2:T)-x(1:T-1);
    T  = rows(Dx);
    rhv = Dx(lags:T-1);
    j = 2;             
    while j <= lags;
        rhv = [rhv Dx(lags+1-j:T-j)];
        j = j+1;
    end;
    lhv = Dx(lags+1:T);
    result = ols(lhv,[ones(size(lhv)) rhv]);
    b1 = result.beta;
    
    amat = (b1(2:rows(b1))');
    cofst = 1;
    if lags > 1;
        amat = [amat;eye(lags-1) zeros(lags-1,1)];
        cofst = [1 zeros(1,lags-1)];
    end;
    cofst = cofst*amat*inv(eye(lags)-amat);
    stat  = rhv*(cofst');
