function [dataOUT,date] = GetDataANN(dataIN,SysId)

% Construct the state variables.
% dataIN = 1890 to 1995.

shortyield = dataIN(:,7)./100;				% 1890 to 1995.
TBill = shortyield(1:rows(shortyield)-1);	% 1891 to 1995.
ppirate = dataIN(:,3);							% 1890 to 1995.
vwretd = dataIN(:,6);							% 1890 to 1995.
vwindx = dataIN(:,4);							% 1890 to 1995.
div = dataIN(:,5);								% 1890 to 1995.
longyield = dataIN(:,8)./100;					% 1890 to 1995.
loglongyield = log(1+longyield);				% 1890 to 1995.
date = dataIN(:,1);

% -- Construct Bond Return: 1891 to 1995 -- %
n = 20;
T = rows(loglongyield);
Dcn = (1-(1+longyield).^(-n)) ./ (1-1./(1+longyield));
logBondRet = Dcn(1:T-1).*loglongyield(1:T-1) - (Dcn(1:T-1) - 1).*loglongyield(2:T);		% 1891 to 1995.

% -- Construct Log Excess Returns -- %
logTBill = log(1+TBill);											% 1891 to 1995.
RealTBill = logTBill - log(1+ppirate(2:rows(ppirate)));	% 1891 to 1995.
logPPI = log(1+ppirate);
exStock = log(1+vwretd(2:rows(vwretd))) - logTBill;		% 1891 to 1995.
exBond = logBondRet - logTBill;									% 1891 to 1995.

% -- Construct log dividend price ratio -- %
DivPrice = log(div) - log(vwindx);								% 1890 to 1995.

% -- Construct Relative Bill rate = First difference of Nominal short rate -- %
rb = logTBill(2:rows(logTBill))- logTBill(1:rows(logTBill)-1);		% 1892 to 1995.

% -- Construct Yield Spread -- %
spread = loglongyield - log(1+shortyield);					% 1890 to 1995.

% -- Collect the Series -- %

% RealTBill = 1891 to 1995.
% exStock   = 1891 to 1995.
% exBond    = 1891 to 1995.
% DivPrice  = 1890 to 1995.
% rb			= 1892 to 1995.
% spread 	= 1890 to 1995.

if SysId == 1
   dataOUT = [RealTBill(2:rows(RealTBill)), exStock(2:rows(exStock)), exBond(2:rows(exBond)), DivPrice(3:rows(DivPrice)), rb];
elseif SysId == 2
   dataOUT = [RealTBill(2:rows(RealTBill)), exStock(2:rows(exStock)), exBond(2:rows(exBond)), DivPrice(3:rows(DivPrice)), rb, spread(3:rows(spread))];
elseif SysId == 3
   %dataOUT = [logTBill(3:rows(logTBill)), exStock(2:rows(exStock)-1), exBond(2:rows(exBond)-1), DivPrice(3:rows(DivPrice)-1), spread(3:rows(spread)-1), logPPI(3:rows(logPPI)-1)];
	%before 6/16/00 (use this one for graphs.m):
	%dataOUT = [RealTBill(2:rows(RealTBill)-1), exStock(2:rows(exStock)-1), exBond(2:rows(exBond)-1), DivPrice(3:rows(DivPrice)-1), spread(3:rows(spread)-1), logTBill(3:rows(logTBill))];
	%John's new ordering as of 6/16/00 DO NOT USE FOR GRAPHS.M:
	dataOUT = [RealTBill(2:rows(RealTBill)-1), exStock(2:rows(exStock)-1), exBond(2:rows(exBond)-1), logTBill(3:rows(logTBill)), DivPrice(3:rows(DivPrice)-1), spread(3:rows(spread)-1)];
	date = date(2:rows(date)-1);
	%me: 6/18
	%dataOUT = [RealTBill(2:rows(RealTBill)-1), exStock(2:rows(exStock)-1), exBond(2:rows(exBond)-1), logTBill(3:rows(logTBill)), spread(3:rows(spread)-1), DivPrice(3:rows(DivPrice)-1)];
	%this is for x-checking w/ lewis (also comments out div correction in main.m):
   	%dataOUT = [RealTBill(2:rows(RealTBill)), exStock(2:rows(exStock)), exBond(2:rows(exBond)), DivPrice(3:rows(DivPrice)), spread(3:rows(spread)), rb];
   	%dataOUT = dataOUT(1:rows(dataOUT)-1,:);
end;

%A = sortrows([randn(rows(dataOUT),1) dataOUT(:,3)],1);
%dataOUT(:,3) = A(:,2);