function [b0,b1,tb0,tb1,S,Rsqmat,CorrResid] = GetParms_res(z,nlag,L,ind,SM)

% JW 6/20: Adaptation of Lewis' code which estimates the VAR on
% demeaned data and then reports a PHI0 which causes the sample means to match
% the steady-state mean of the VAR, which is inv(eye - PHI1)*PHI0.

% Run VAR estimation to get the underlying parameters.
% It estimates coefficients, Newey-West t stats, and variance-covariance
% matrix of residuals of a VAR(p) for z(t), i.e.
%
%    		z(t) = b(0) + b(1)*z(t-1) + ... + b(p)*z(t-p) + eps(t)
%
% Syntaxis:
%
%				{b0,b1,tb0,tb1,S} = var(z,p,l,ind)
%
% where: z   = (T*k) matrix of obs., with series by columns.
%        p   = order of VAR.
%        L   = window width for NW standard errors (0 computes White errors)
%        ind = 0 if no constant included
%              1 if constant included.
%        b0  = intercept coefficients.
%			b1  = [b(1) b(2) ... b(p)] coefficients.
%        tb0 = t-stats of b0.
%			tb1 = t-stats of b1. 
%        S   = (k*k) covariance matrix of residuals
%			Rsqmat = k-by-1 vector of R^2's.
%			CorrResid = Correlation matrix of the residuals.

k      = cols(z);
t      = rows(z);
%bmat   = zeros(k,ind*1+(nlag*k));
bmat   = zeros(k,(nlag*k));

tmat   = zeros(k,ind*1+(nlag*k));
e      = zeros(t-nlag,k);
Rsqmat = zeros(k,1);

%JW: Save sample means and remove them from z:

if exist('SM')
	SampleMeans = SM';
else
	SampleMeans = mean(z)';
        SM_curr = mean(z(nlag+1:t,:))';
        SM_lag = mean(z(1:t-1,:))';
end
z_old = z;

for i=1:k				% Looping over each variable.
	y = z(nlag+1:t,i)-ones(rows(z)-1,1)*SM_curr(i)';
	x = z(nlag:t-1,:)-ones(rows(z)-1,1)*SM_lag';
	%if ind == 1;
	%	x = [ones(t-nlag,1),x];
	%end;
	b = inv(x'*x)*x'*y;
	bmat(i,:) = b';
	%e(:,i) = (y-x*b);								%JW CO
	%tmat(i,:) = (b./sqrt(diag(hacnw(x,e(:,i),L))))';		%JW CO
	%Rsqmat(i) = 1 - var(e(:,i))/var(y);				%JW CO
end;

%JW: Re-form first column of the b matrix to match restriction
b1  = bmat;

b0 = (eye(rows(b1)) - b1)*SampleMeans;
bmat = [b0 b1];
z = z_old; %restore z to produce correct errors

%JW: loop through to get regression errors and calculate errors for coefficients
for i = 1:k
	y = z(nlag+1:t,i);
	x = z(nlag:t-1,:);
	for j = 1:(nlag-1)
		x = [x,z(nlag-j:t-1-j,:)];	
	end;
	if ind == 1;
		x = [ones(t-nlag,1),x];
	end;
	b = bmat(i,:)';
	e(:,i) = (y-x*b);
	tmat(i,:) = (b./sqrt(diag(hacnw(x,e(:,i),L))))';
	Rsqmat(i) = 1 - var(e(:,i))/var(y);
end	

b0  = bmat(:,1);
b1  = bmat(:,2:cols(bmat));
tb0 = tmat(:,1);
tb1 = tmat(:,2:cols(tmat));
S   = e'*e/(rows(e));				% ML estimatioin of the cov-var matrix %
CorrResid = corrcoef(e);			% Correlation matrix of residuals %
