% Generates historical allocations from state variables; plots state variables
% and corresponding allocations nicely on a page.  This will work if run after
% main.m is run with one of the InflStateVar_* programs run within it.  Should
% really only be run with the InflStateVar_NB program.

% Annual sample starts at:  1893
% Quarterly sample starts at: 

if SampleFreq == 3
	dates = linspace(1893, 1893+rows(dataOUT)-1,rows(dataOUT));
elseif SampleFreq == 2
	dates = linspace(1953.5, 1953.5+(rows(dataOUT)-1)/4,rows(dataOUT));
end


myopicD_history = [];
hedgeD_history = [];

for i = 1:size(dataOUT)    % I realize you don't need a loop for this

	CurrStateVar = dataOUT(i,:)';
	myopicD = (1/gama)*inv(SIGMAxx)*(Hx*PHI0+Hx*PHI1*CurrStateVar+0.5*d+(1-gama)*SIGMA1x )*100;
	hedgeD = -(1/gama)*inv(SIGMAxx)*( ((1-gama)/(psi-1))*(LAMDA0+LAMDA1*CurrStateVar) )*100;

	myopicD_history = [myopicD_history; myopicD'];
	hedgeD_history = [hedgeD_history; hedgeD'];

end


totalD_history = myopicD_history + hedgeD_history;
cash_history = 100 - sum(totalD_history')';

if 1

figure;

ubertitle = [];
ubertitle(1,:) = 'real rate           ';
ubertitle(2,:) = 'excess stock return ';
ubertitle(3,:) = 'excess bond return  ';
ubertitle(4,:) = 'nominal yield       ';
ubertitle(5,:) = 'dividend-price ratio';
ubertitle(6,:) = 'yield spread        ';


subplot(3,1,1);
plot(dates,dataOUT(:,1),'k-.',dates,dataOUT(:,2),'k-',dates,dataOUT(:,3),'k:');
legend('real rate', 'excess stock ret.', 'excess bond ret.');
%axis([1953 2000 -1 .5]);

subplot(3,1,2);
plot(dates,dataOUT(:,4),'k-',dates, dataOUT(:,6),'k:');
legend('nominal yield', 'yield spread');
%axis([1953 2000 -.2 .2]);

subplot(3,1,3);
plot(dates,dataOUT(:,5),'k');
legend('div.-price ratio');
%axis([1953 2000 -4 -2]);



figure

subplot(3,1,1);
plot(dates, [cash_history totalD_history]);
plot(dates, cash_history, 'k-.', dates, totalD_history(:,1), 'k-', dates, totalD_history(:,2), 'k:');
legend('cash','total stock', 'total bond');
%axis([1953 2000 -1000 1000]);



subplot(3,1,2);
plot(dates, myopicD_history(:,1), 'k-', dates, myopicD_history(:,2), 'k:');
legend('myopic stock', 'myopic bond');
%axis([1953 2000 -1000 1000]);

subplot(3,1,3);
plot(dates, hedgeD_history(:,1), 'k-', dates, hedgeD_history(:,2), 'k:');
legend('hedging stock', 'hedging bond');
%axis([1953 2000 -1000 1000]);

end
