PSIVALUE_2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Some settings that shouldn't change:

rhovec = .92;
CritValDelta = .00001;
CritValB = .000000001;
g = 20;

if SampleFreq == 1
        rhovec = rhovec.^(1/12);
elseif SampleFreq == 2
        rhovec = rhovec.^(1/4);
elseif SampleFreq == 3   
        rhovec = rhovec;
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ASSEMBLE the variables.

SysId = 3;	% Legacy -- used to designate appropriate VAR system.

if SampleFreq == 1;   
	if SubSample == 0
		load dataMTH.asc;
		dataOUT = GetDataMTH(dataMTH,SysId);
	elseif SubSample == 1
		load dataMTHsub.asc;
		dataOUT = GetDataMTHsub(dataMTHsub,SysId);
	end
elseif SampleFreq == 2
	load dataQTR.asc;
	[dataOUT,date]  = GetDataQTR(dataQTR,SysId,8);      % 8th col = 5-yr bond;
	if SubSample == 1
		dataOUT_old = dataOUT;
		dataOUT = dataOUT(1:106,:);
	elseif SubSample == 2
		dataOUT_old = dataOUT;
		dataOUT = dataOUT(106:rows(dataOUT),:);
	end
elseif SampleFreq == 3          
	load dataANN.asc;            
	dataOUT = GetDataANN(dataANN,SysId);
end;
      

% At this point, we should have dataOUT loaded according to the legacy methods...
% The order of the variables should be
%	1) Nominal short rate
%	2) Stock, excess return over nominal short rate
%	3) Nominal bond, excess return over nominal short rate
%	5) Nominal short yield
%	6) Dividend-price ratio
%	7) Yield spread
% As you can see, (4) is missing.  ((0) is supplied by the VAR program).  The problem
% with just plugging in (4) here is that it requires slicing one datapoint.  For strict
% comparability, we ought to create a special case here.  However, since special cases
% are abhorrent and there are good statistical reasons for using the same sample period
% across portfolio choice exercises, we will proceed by just adding (4), and thereby slicing
% the datapoint for all possible permutations of variables.

%Add the real consol bond excess return over nominal short rate, (4):

	% Do the var estimation given the restriction that the steady state mean implied by the VAR is equal to
	% the mean of the state variables
	[PHI0o,PHI1o,tPHI0o,tPHI1o,SIGMAvo,Rsqveco,CORRvo] = GetParms_res(dataOUT,1,0,1);

	rhoConsol = rhovec;

	% "newdataOUT" contains the consol bond return where the nominal bond return formerly was
%	newdataOUT = GetConsolBondRet(dataOUT, PHI0o, PHI1o, SIGMAvo, rhoConsol);
	newdataOUT = GetConsolBondRetold(dataOUT, PHI0o, PHI1o, rhoConsol);
	%!!! use "old" version of GetConsolBondRet.  GetConsolBondRetold is the right one.

	% Re-insert nominal bond into dataOUT:
	newdataOUT = [newdataOUT(:,1:2) dataOUT(2:rows(dataOUT),3) newdataOUT(:,3:cols(newdataOUT))];
%	newdataOUT = dataOUT;
	% Re-define dataOUT (the dataset used by the VAR inside the numstate loop) to be the dataset
	% with the nominal bond re-inserted
	dataOUT = newdataOUT;

	% Add garbage asset as check -- should be commented out for ordinary operation.
	%dataOUT = [dataOUT(:,1:4) dataOUT(:,2)+randn(size(dataOUT(:,1)))*std(dataOUT(:,2))/10 dataOUT(:,5:7)];

% Now the ordering of state variables in data out is as follows:

% State Variables -- all possible state variables for use
%	0) Constant
%	1) Nominal short rate
%	2) Stock, excess return over nominal short rate
%	3) Nominal bond, excess return over nominal short rate
%	4) Consol bond, excess return over nominal short rate
%	5) Nominal short yield
%	6) Dividend-price ratio
%	7) Yield spread

%StateVariableIsAsset = [0 1 1 0 0 0];  % For when RCB loading is commented out.
StateVariableIsAsset = [0 1 1 1 0 0 0];
%StateVariableIsAsset = [0 1 1 1 1 0 0 0];  % for garbage asset case
			%0/1 vector indicating whether state variable is an excess return
			%on an asset that could (possibly) be used in portfolio choice.
			%Exists for checking purposes -- see below.  Do not change, unless
			%_possible_ assets are added or subtracted.  Choice of assets to 
			%select over is implemented below.


% Note, at present, no re-ordering option available.








%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DETERMINE which state variables and assets are to be used

% The following are selection variable, intended to be changed
%StateVariableUsed = [1 1 1 1 1 1 1]; % set in batch.m
			%0/1 vector indicating whether state variable is to be used in the VAR.

%AssetUsed = [0 1 0 1 0 0 0]; % set in batch.m
			%0/1 vector indicating whether asset is to be used in portfolio choice

% Error checking, self-explanatory
if sum(and(AssetUsed, StateVariableUsed) ~= AssetUsed)
	error('ERROR: For an asset to be used in portfolio choice, it must be a state variable in the VAR.');
end

if sum(or(AssetUsed, StateVariableIsAsset) ~= StateVariableIsAsset)
	disp('ERROR: You may only designate as assets to be used in portfolio choice state variables that are');
	disp('excess returns w.r.t. the nominal short rate.');
	error('');
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CONSTRUCT Hx, the asset selection matrix, appropriately, given the size of the 
% state vector and the AssetsUsed indicator:

m = sum(StateVariableUsed);		% Dimension of the state vector

tempAssetUsed = [];
for iHx = 1:max(size(StateVariableUsed))
	if StateVariableUsed(iHx)
		tempAssetUsed = [tempAssetUsed AssetUsed(iHx)];
	end
end

Hx = [];
tempHx = eye(m);
for iHx = 1:m
	if(tempAssetUsed(iHx))
		Hx = [Hx;tempHx(iHx,:)];
	end
end

H1 = [1 zeros(1,m-1)];

clear iHx tempHx tempAssetUsed

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CONSTRUCT dataOUT to include the appropriate state variables.

newdataOUT = [];
for idO = 1:max(size(StateVariableUsed))
	if StateVariableUsed(idO)
		newdataOUT = [newdataOUT dataOUT(:,idO)];
	end
end
dataOUT = newdataOUT;

clear newdataOUT


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RUN the appropriate programs.
% At present, three options:
%	'ISV'	Influence of State Variables
%	'VDC'	Variance Decomposition
%	'VAR'	VAR -- only runs VAR, to get VAR table

if sum(PROG == 'ISV')==3
	InflStateVar_general;
	processtotex;

elseif sum(PROG == 'VDC')==3

	VarDecomp2;

elseif sum(PROG == 'VAR')==3
	[PHI0,PHI1,tPHI0,tPHI1,SIGMAv,Rsqvec,CORRv] = GetParmsNumState(dataOUT,1,0,1,m,RCBposition);
	signifr2;
end



% save file in name generated by batch.m

if nosave == 0
	save(savefile);
end
